@@ -8,7 +8,7 @@ def getHour(hour_directory):
     os.chdir(hour_directory)
     minutes = os.listdir(hour_directory)
     clips = []
-    for minute in minutes:
+    for minute in minutes[0:2]:
         if minute.endswith(".mp4"):
             try:
                 clips.append(mp.VideoFileClip(minute))
